#
# spec file for package python-PyKMIP
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without python2
Name:           python-PyKMIP
Version:        0.10.0
Release:        8.1
Summary:        KMIP v11 library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/OpenKMIP/PyKMIP
Source:         https://files.pythonhosted.org/packages/source/P/PyKMIP/PyKMIP-%{version}.tar.gz
# PATCH-FIX-UPSTREAM fix-tests-SQLAlchemy-140.patch gh#OpenKMIP/PyKMIP#656 mcepl@suse.com
# fix tests to work with SQLAlchemy >= 1.4.0
Patch0:         fix-tests-SQLAlchemy-140.patch
# https://github.com/OpenKMIP/PyKMIP/issues/668
Patch1:         python-PyKMIP-no-mock.patch
# PATCH-FIX-OPENSUSE crypto-39.patch gh#OpenKMIP/PyKMIP#689
Patch2:         crypto-39.patch
# PATCH-FIX-UPSTREAM fix_test_mac_with_cryptographic_failure.patch gh#OpenKMIP/PyKMIP#702
Patch3:         fix_test_mac_with_cryptographic_failure.patch
BuildRequires:  %{python_module SQLAlchemy}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module testtools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-SQLAlchemy
Requires:       python-cryptography
Requires:       python-requests
Requires:       python-six
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%if %{with python2}
BuildRequires:  python-enum34
%endif
%ifpython2
Requires:       python-enum34
%endif
%python_subpackages

%description
PyKMIP is a Python implementation of the Key Management Interoperability
Protocol (KMIP). KMIP is a client/server communication protocol for the
storage and maintenance of key, certificate, and secret objects. The standard
is governed by the `Organization for the Advancement of Structured Information
Standards`_ (OASIS). PyKMIP supports a subset of features in versions
1.0 - 1.2 of the KMIP specification.

%prep
%autosetup -p1 -n PyKMIP-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/pykmip-server
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest kmip/tests/unit

%post
%python_install_alternative pykmip-server

%postun
%python_uninstall_alternative pykmip-server

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/kmip
%{python_sitelib}/PyKMIP-%{version}*-info
%python_alternative %{_bindir}/pykmip-server

%changelog
* Fri Sep  8 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add upstream patch fix_test_mac_with_cryptographic_failure.patch
  gh#OpenKMIP/PyKMIP#702, this fixes the issue with the
  test_mac_with_cryptographic_failure.
* Thu Feb 23 2023 Daniel Garcia <daniel.garcia@suse.com>
- Disable broken test, test_mac_with_cryptographic_failure,
  gh#OpenKMIP/PyKMIP#690
* Thu Jan 26 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add crypto-39.patch to make it work with python-cryptography >= 39.0.0
  gh#OpenKMIP/PyKMIP#689
* Wed May  4 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  fix https://github.com/OpenKMIP/PyKMIP/issues/668
  + python-PyKMIP-no-mock.patch
* Fri Sep 24 2021 Matej Cepl <mcepl@suse.com>
- Remove SQL-issues.patch with the patch
  fix-tests-SQLAlchemy-140.patch which actually resolves the
  problems (gh#OpenKMIP/PyKMIP#656).
* Sat Jun  5 2021 Matej Cepl <mcepl@suse.com>
- Add SQL-issues.patch skipping tests failing due to
  incompatibilities with the current version of SQLAlchemy
  (gh#OpenKMIP/PyKMIP#649).
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Mon Mar 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.10.0
  * Add server debug logging for message encodings
  * Add server Locate filtering for all currently supported attributes
  * Add server Locate filtering using offset and maximum item constraints
  * Add server cryptography engine support for AES GCM mode
  * Add server support for the SplitKey object
  * Add client/server support for the ApplicationSpecificInformation attribute
  * Add client/server support for the ObjectGroup and Sensitive attributes
  * Add client/server support for the DeleteAttribute operation
  * Add client/server support for the SetAttribute operation
  * Add client/server support for the ModifyAttribute operation
  * Add a variety of unit and integration tests to cover all new functionality
  * Add new ProxyKmipClient demo scripts to show how to use the new operations
  * Add pending deprecation warnings for Python 2.7 and 3.4 due to their EOL
  * Update server Locate filtering to return results sorted by creation date
  * Update encoding support for SplitKey objects
  * Update the Travis CI configuration to better support default Python versions
  * Update library and testing dependencies to maintain Python 3.4 support
  * Update the library documentation to reflect new features and security details
  * Fix a bug with how key pair names are handled by the client for KMIP 2.0
* Thu Jul 25 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.9.1
  * Add various support for KMIP 2.0
  * Add support for Python 3.7
  * Add utilities to handle bit mask style enumerations
  * Update library logging defaults to log at INFO but still support DEBUG
  * Update the PyKMIP clients to support changing their KMIP version
  * Update the server TLS handshake handling to avoid thread hanging
  * Remove escape sequences to comply with Python 3.6 style deprecations
  * See upstream changelog for more
* Sun Jan  6 2019 Dirk Mueller <dmueller@suse.com>
- update to 0.8.0:
  * Add Sphinx-based client and server library documentation
  * Add server support for third-party authentication systems
  * Add client support for the Check operation
  * Add client support for the Rekey operation
  * Add client support for attestation credentials
  * Add a functional test suite for server authentication and access control
  * Add payloads for the Archive, Cancel, and GetUsageAllocation operations
  * Add payloads for the ObtainLease, Poll, and Recover operations
  * Update the server to support group-based operation policies
  * Update the server to support live loading of operation policy files
  * Update the server to support custom backend database file paths
  * Update the server to raise PermissionDenied on access control violations
  * Update the client to support custom configuration file paths
  * Update the ProxyKmipClient to support custom names for the Register operation
  * Update the ProxyKmipClient to set cryptographic usage masks for Derived keys
  * Update the README to reference the new documentation
  * Update the Travis CI configuration to include building the documentation
  * Update the Travis CI configuration to run integration and functional tests
  * Remove support for Python 3.3
  * Fix a denial-of-service bug by setting the server socket timeout
  * Fix a ProxyKmipClient bug with generic cryptographic parameter handling
  * Fix a ProxyKmipClient bug with cryptographic usage mask processing
* Thu Feb 15 2018 tbechtold@suse.com
- update to 0.7.0:
  * Add support for Python 3.6
  * Add support for the InitialDate attribute
  * Add server support for the GetAttributeList operation
  * Add server support for the Locate operation
  * Add client and server support for the MAC operation
  * Add client and server support for the Revoke operation
  * Add client and server support for the Encrypt operation
  * Add client and server support for the Decrypt operation
  * Add client and server support for the DeriveKey operation
  * Add client and server support for the Sign operation
  * Add client and server support for the SignatureVerify operation
  * Add client and server support for retrieving wrapped keys
  * Add client and server support for storing wrapped keys
  * Add KMIP 1.4 enumerations
  * Add server config option enabling certificate extension checks
  * Add server config option defining set of usable TLS ciphers
  * Add server config option setting the server log level
  * Update the server to enforce checking object state and usage masks
  * Update server Locate support to allow object name filtering
  * Remove support for Python 2.6
  * Fix bug with multithreading support with the SQLite backend
  * Fix bug with how open() is mocked in the server test suite
  * Fix bug with mismapped polymorphic identity for certificate objects
  * Fix bug with socket interrupt handling under Python 3.5
  * Fix bug with detached instance errors in the server test suite
- Use pytest for testing. That's what upstream does
- Use fdupes
* Fri Aug 25 2017 tbechtold@suse.com
- update to 0.6.0:
  * Add support for Python 3.5
  * Add support for the State and OperationPolicyName attributes
  * Add server support for the Activate and GetAttributes operations
  * Add server support for certificate-based client authentication
  * Add server support for object access control via operation policies
  * Add server support for loading of user-defined operation policies
  * Add client support for the GetAttributes operation
  * Update clients to support operation policy names with objects
  * Update ProxyKmipClient to support names when creating new objects
  * Remove coveralls integration
  * Fix bug with early server termination on missing request credential
  * Fix bug with closing the client while unconnected to a server
  * Fix bug with default values overriding server config file settings
  * Fix bug with early server termination on bad client certificates
  * Fix bug with deprecated usage of the bandit config file
  * Fix bug with ProxyKmipClient registering unset object attributes
- convert to singlespec
* Tue May 24 2016 slunkad@suse.com, johannes.grassler@suse.com
- Initial Packaging (version 0.5.0)
